@@ -905,7 +905,7 @@ class Grid:
             delta_x <= self.__image.shape[0]
             and self.__nodes['pixel_x_axis'][node] + delta_x >= 0
             and self.__nodes[
-                'pixel_y_axis'][node] + delta_y <= self.get_image.shape[1]
+                'pixel_y_axis'][node] + delta_y <= self.get_image().shape[1]
             and self.__nodes[
                 'pixel_y_axis'][node] + delta_y >= 0)
 
